@@ -21,6 +21,8 @@
 #ifndef CDK_TYPES_H
 #define CDK_TYPES_H
 
+#include <gcrypt.h> /*FIXME!*/
+
 #ifndef HAVE_BYTE_TYPEDEF
 # undef byte
   typedef unsigned char byte;
@@ -46,7 +48,6 @@
 
 
 struct cdk_verify_result_s;
-typedef struct cdk_verify_result_s *Verify_Result;
-
+typedef struct cdk_verify_result_s *_cdk_verify_result_t;
 
 #endif /* CDK_TYPES_H */
